aboutsummaryrefslogtreecommitdiff
path: root/drivers/i2c/i2c-emul-uclass.c
diff options
context:
space:
mode:
authorTom Rini <trini@konsulko.com>2020-12-14 18:57:57 -0500
committerTom Rini <trini@konsulko.com>2020-12-14 18:57:57 -0500
commit8351a29d2df18c92d8e365cfa848218c3859f3d2 (patch)
tree5d29001be9accfb8029df9d9ed78fba196ee07b9 /drivers/i2c/i2c-emul-uclass.c
parentddaa94978583d07ec515e7226e397221d8cc44c8 (diff)
parentb7bbd553de0d9752f919dfc616f560f6f2504c14 (diff)
Merge tag 'dm-pull-14dec20' of git://git.denx.de/u-boot-dm into next
Driver model tidy-up for livetree Driver model big rename for consistency Python 3 clean-ups for patman Update sandbox serial driver to use membuff
Diffstat (limited to 'drivers/i2c/i2c-emul-uclass.c')
-rw-r--r--drivers/i2c/i2c-emul-uclass.c21
1 files changed, 10 insertions, 11 deletions
diff --git a/drivers/i2c/i2c-emul-uclass.c b/drivers/i2c/i2c-emul-uclass.c
index 84b6a219d1..085b824e89 100644
--- a/drivers/i2c/i2c-emul-uclass.c
+++ b/drivers/i2c/i2c-emul-uclass.c
@@ -14,7 +14,7 @@
* i2c emulation works using an 'emul' node at the bus level. Each device in
* that node is in the UCLASS_I2C_EMUL uclass, and emulates one i2c device. A
* pointer to the device it emulates is in the 'dev' property of the emul device
- * uclass platdata (struct i2c_emul_platdata), put there by i2c_emul_find().
+ * uclass plat (struct i2c_emul_plat), put there by i2c_emul_find().
* When sandbox wants an emulator for a device, it calls i2c_emul_find() which
* searches for the emulator with the correct address. To find the device for an
* emulator, call i2c_emul_get_device().
@@ -24,27 +24,27 @@
*/
/**
* struct i2c_emul_uc_platdata - information about the emulator for this device
*
* This is used by devices in UCLASS_I2C_EMUL to record information about the
* device being emulated. It is accessible with dev_get_uclass_platdata()
*
* @dev: Device being emulated
*/
-struct i2c_emul_uc_platdata {
+struct i2c_emul_uc_plat {
struct udevice *dev;
};
struct udevice *i2c_emul_get_device(struct udevice *emul)
{
- struct i2c_emul_uc_platdata *uc_plat = dev_get_uclass_platdata(emul);
+ struct i2c_emul_uc_plat *uc_plat = dev_get_uclass_plat(emul);
return uc_plat->dev;
}
int i2c_emul_find(struct udevice *dev, struct udevice **emulp)
{
- struct i2c_emul_uc_platdata *uc_plat;
+ struct i2c_emul_uc_plat *uc_plat;
struct udevice *emul;
int ret;
@@ -54,7 +54,7 @@ int i2c_emul_find(struct udevice *dev, struct udevice **emulp)
log_err("No emulators for device '%s'\n", dev->name);
return ret;
}
- uc_plat = dev_get_uclass_platdata(emul);
+ uc_plat = dev_get_uclass_plat(emul);
uc_plat->dev = dev;
*emulp = emul;
@@ -64,14 +64,13 @@ int i2c_emul_find(struct udevice *dev, struct udevice **emulp)
UCLASS_DRIVER(i2c_emul) = {
.id = UCLASS_I2C_EMUL,
.name = "i2c_emul",
- .per_device_platdata_auto_alloc_size =
- sizeof(struct i2c_emul_uc_platdata),
+ .per_device_plat_auto = sizeof(struct i2c_emul_uc_plat),
};
/*
- * This uclass is a child of the i2c bus. Its platdata is not defined here so
+ * This uclass is a child of the i2c bus. Its plat is not defined here so
* is defined by its parent, UCLASS_I2C, which uses struct dm_i2c_chip. See
- * per_child_platdata_auto_alloc_size in UCLASS_DRIVER(i2c).
+ * per_child_plat_auto in UCLASS_DRIVER(i2c).
*/
UCLASS_DRIVER(i2c_emul_parent) = {
.id = UCLASS_I2C_EMUL_PARENT,
@@ -24,27 +24,27 @@
*/
/**
- * struct i2c_emul_uc_platdata - information about the emulator for this device
+ * struct i2c_emul_uc_plat - information about the emulator for this device
*
* This is used by devices in UCLASS_I2C_EMUL to record information about the
@@ -24,27 +24,27 @@
*
* This is used by devices in UCLASS_I2C_EMUL to record information about the
- * device being emulated. It is accessible with dev_get_uclass_platdata()
+ * device being emulated. It is accessible with dev_get_uclass_plat()
*
* @dev: Device being emulated